Creation

Enum Creation 

pub enum Creation {
    CopyFromReadOnly,
    Execute,
}
Variants



CopyFromReadOnly

Run the code once and copy the data from its output to the writable location. This is fast but won’t work if absolute paths are produced by the script.

Limitation

Cannot handle symlinks currently. Waiting for this PR.



Execute

Run the code in the writable location. That way, absolute paths match the location.