pub enum FixtureState<'a> {
Uninitialized(&'a Path),
Fresh(&'a Path),
}Expand description
Indicates the state of a fixture when a closure is called.
Variants
Uninitialized(&'a Path)
The fixture is newly created and needs post-processing.
The closure should perform any necessary modifications to the fixture directory and compute its return value.
Fresh(&'a Path)
The fixture was already created (cached) and only needs to produce a return value.
The closure should NOT modify the fixture directory, but only compute and return a value based on the existing contents.
Implementations
Sourceimpl FixtureState<'_>
impl FixtureState<'_>