invoke_bash

Function invoke_bash 

pub fn invoke_bash(cwd: impl AsRef<Path>, script: &str)
Run script with bash_program() in cwd.

Standard input is disconnected while standard output and error stay attached to the inherited handles.

Panics

This function expects the script to succeed and will panic otherwise.