scripted_fixture_writable

Function scripted_fixture_writable 

pub fn scripted_fixture_writable(
    script_name: impl AsRef<Path>,
) -> Result<TempDir>
Run the executable at script_name, like make_repo.sh to produce a writable directory to which the tempdir is returned. It will be removed automatically, courtesy of tempfile::TempDir.

Note that script_name is only executed once, so the data can be copied from its read-only location.