PostResult

Type Alias PostResult 

pub type PostResult<T = ()> = Result<T, Box<dyn Error + Send + Sync>>;
A result type for post-processing closures in *_with_post fixture functions.

The closure can return any value T, which will be returned alongside the fixture path. This is useful for computing values based on the fixture contents.

Aliased Type

pub enum PostResult<T = ()> {
    Ok(T),
    Err(Box<dyn Error + Send + Sync>),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(Box<dyn Error + Send + Sync>)

Contains the error value